def format_extracted_text(extracted_text):
    formatted = list(extracted_text.split())
    formatted = formatted[7:]
    headers = formatted[0:4]
    headers = [headers[0], headers[1], ' '.join(headers[2:])]
    data = formatted[4:]
    formatted_data = []
    i = 0
    while i < len(data):
        item_start = i
        item_end = i + 1
        while item_end < len(data) and not data[item_end].isdigit():
            item_end += 1
        item = " ".join(data[item_start:item_end])
        
        if item_end < len(data):
            quantity = data[item_end]
            i = item_end + 1
        else:
            break

        bar_designation_start = i
        bar_designation_end = bar_designation_start + 2
        if len(data) > bar_designation_end:
            bar_designation = " ".join(data[bar_designation_start:bar_designation_end])
            i = bar_designation_end
        else:
            bar_designation = " ".join(data[bar_designation_start:])
            i = len(data)
        
        formatted_data.append([item, quantity, bar_designation])
    
    return formatted_data


from azure.ai.formrecognizer import DocumentAnalysisClient
from azure.core.credentials import AzureKeyCredential
from .utils import get_credentials

def extract_text_from_document(document_path):
    API_KEY, ENDPOINT = get_credentials()
    document_analysis = DocumentAnalysisClient(endpoint=ENDPOINT, credential=AzureKeyCredential(API_KEY))
    with open(document_path, 'rb') as f:
        poller = document_analysis.begin_analyze_document("prebuilt-document", f.read())
        result = poller.result()
        extracted_text = ""
        for page in result.pages:
            for line in page.lines:
                extracted_text += line.content + " "
        return extracted_text.strip()
    





import os

def get_form(filled_out=False, output_path=None):
    package_dir = os.path.dirname(os.path.abspath(__file__))
    data_dir = os.path.join(package_dir, 'data')

    if filled_out:
        form_file = 'standard-form-filled-out.pdf'
    else:
        form_file = 'standard_form.pdf'

    pdf_file = os.path.join(data_dir, form_file)

    # Print the absolute paths
    print(f"Package directory: {package_dir}")
    print(f"Data directory: {data_dir}")
    print(f"PDF file path: {pdf_file}")

    if output_path is None:
        output_path = os.path.join(os.getcwd(), form_file)
    else:
        output_path = os.path.join(output_path, form_file)

    with open(pdf_file, 'rb') as src, open(output_path, 'wb') as dst:
        dst.write(src.read())

    return output_path